#include "consoleextensions.hpp"

#include <components/interpreter/interpreter.hpp>

namespace MWScript
{
    namespace Console
    {
        void installOpcodes(Interpreter::Interpreter& interpreter) {}
    }
}
